summaryrefslogtreecommitdiffhomepage
path: root/dev/Boot/src/BootThread.cc
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2025-01-01 23:25:44 +0100
committerAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2025-01-01 23:25:44 +0100
commite154cbf9a2a9eedd4c122d6619f25d29e04610ef (patch)
treec02e69a8c41f58ebedc2e1cc0fbc3bb5437116d4 /dev/Boot/src/BootThread.cc
parentad97dd0ac528b837d14e9236369c823dec66aea8 (diff)
IMPL: Update to fixes to kernel and bootloader.
Signed-off-by: Amlal El Mahrouss <amlal.elmahrouss@icloud.com>
Diffstat (limited to 'dev/Boot/src/BootThread.cc')
-rw-r--r--dev/Boot/src/BootThread.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/dev/Boot/src/BootThread.cc b/dev/Boot/src/BootThread.cc
index a3bc3500..782483f9 100644
--- a/dev/Boot/src/BootThread.cc
+++ b/dev/Boot/src/BootThread.cc
@@ -18,13 +18,13 @@
/// @brief External boot services symbol.
EXTERN EfiBootServices* BS;
/// @note BThread doesn't parse the symbols so doesn't nullify them, .bss is though.
namespace Boot
{
EXTERN_C Void rt_jump_to_address(VoidPtr code, HEL::BootInfoHeader* handover, UInt8* stack);
- BThread::BThread(VoidPtr blob)
+ BootThread::BootThread(VoidPtr blob)
: fBlob(blob), fStartAddress(nullptr)
{
// detect the format.
@@ -167,7 +167,7 @@ namespace Boot
}
/// @note handover header has to be valid!
- Int32 BThread::Start(HEL::BootInfoHeader* handover, Bool own_stack)
+ Int32 BootThread::Start(HEL::BootInfoHeader* handover, Bool own_stack)
{
HEL::HandoverProc err_fn = [](HEL::BootInfoHeader* rcx) -> Int32 {
fb_render_string("BootZ: Invalid Boot Image...", 50, 10, RGB(0xFF, 0xFF, 0xFF));
@@ -196,17 +196,17 @@ namespace Boot
return NO;
}
- const Char* BThread::GetName()
+ const Char* BootThread::GetName()
{
return fBlobName;
}
- Void BThread::SetName(const Char* name)
+ Void BootThread::SetName(const Char* name)
{
CopyMem(fBlobName, name, StrLen(name));
}
- bool BThread::IsValid()
+ bool BootThread::IsValid()
{
return fStartAddress != nullptr;
}
@@ -18,13 +18,13 @@
/// @brief External boot services symbol.
EXTERN EfiBootServices* BS;
-/// @note BThread doesn't parse the symbols so doesn't nullify them, .bss is though.
+/// @note BootThread doesn't parse the symbols so doesn't nullify them, .bss is though.
namespace Boot
{